@@ -214,6 +214,8 @@ def p_files(t):
     elif len(t) == 5:
         if t[2] in t.parser.tags:
             t[0] = [t[2]] + t[3]
+        else:
+            t[0] = t[3]
     else:
         assert False
 
